@@ -17,41 +17,39 @@ SEXP rgeos_binpredfunc_prepared(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid,
 
     GEOSContextHandle_t GEOShandle = getContextHandle(env);    
     
-	GEOSGeom geom1 = rgeos_convert_R2geos(env, spgeom1);
-	int type1 = GEOSGeomTypeId_r(GEOShandle, geom1);
-	
-	GEOSGeom geom2 = (spgeom2 == R_NilValue) ? geom1 : rgeos_convert_R2geos(env, spgeom2);
-	int type2 = GEOSGeomTypeId_r(GEOShandle, geom2);
-	
+    GEOSGeom geom1 = rgeos_convert_R2geos(env, spgeom1);
+    int type1 = GEOSGeomTypeId_r(GEOShandle, geom1);
+    
+    GEOSGeom geom2 = (spgeom2 == R_NilValue) ? geom1 : rgeos_convert_R2geos(env, spgeom2);
+    int type2 = GEOSGeomTypeId_r(GEOShandle, geom2);
+    
     int sym_ans = (spgeom2 == R_NilValue);
-
-
-	int m = (LOGICAL_POINTER(byid)[0] && type1 == GEOS_GEOMETRYCOLLECTION) ? 
-				GEOSGetNumGeometries_r(GEOShandle, geom1) : 1;
+    
+    int m = (LOGICAL_POINTER(byid)[0] && type1 == GEOS_GEOMETRYCOLLECTION) ? 
+                GEOSGetNumGeometries_r(GEOShandle, geom1) : 1;
     int n = (LOGICAL_POINTER(byid)[1] && type2 == GEOS_GEOMETRYCOLLECTION) ?
-				GEOSGetNumGeometries_r(GEOShandle, geom2) : 1;
-	
+                GEOSGetNumGeometries_r(GEOShandle, geom2) : 1;
     
     if (m == -1) error("rgeos_binpredfunc: invalid number of subgeometries in geometry 1");
     if (n == -1) error("rgeos_binpredfunc: invalid number of subgeometries in geometry 2");
     
-	int pc = 0;
-	SEXP ans;
+    int pc = 0;
+    SEXP ans;
     PROTECT(ans = NEW_LOGICAL(m*n)); pc++;
     
     for(int i=0; i<m; i++) {
         
-		GEOSGeom curgeom1 = (m > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom1, i) : geom1;
+        const GEOSGeometry *curgeom1 = (m > 1) ? GEOSGetGeometryN_r(GEOShandle, geom1, i) : geom1;
         if (curgeom1 == NULL) 
             error("rgeos_binpredfunc: unable to get subgeometries from geometry 1");
-		
-		const GEOSPreparedGeometry *prepgeom = GEOSPrepare_r(GEOShandle, curgeom1);
+        
+        const GEOSPreparedGeometry *prepgeom = GEOSPrepare_r(GEOShandle, curgeom1);
 
         for(int j=0; j<n; j++) {
             if(sym_ans && j > i)
                 break;
             
-			GEOSGeom curgeom2 = (n > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom2, j) : geom2;
+            const GEOSGeometry *curgeom2 = (n > 1) ? GEOSGetGeometryN_r(GEOShandle, geom2, j) : geom2;
             if (curgeom2 == NULL) 
                 error("rgeos_binpredfunc: unable to get subgeometries from geometry 2");
             
@@ -64,13 +62,13 @@ SEXP rgeos_binpredfunc_prepared(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid,
                 LOGICAL_POINTER(ans)[n*j+i] = val;
         
         }
-		
-		GEOSPreparedGeom_destroy_r(GEOShandle, prepgeom);
+        
+        GEOSPreparedGeom_destroy_r(GEOShandle, prepgeom);
     }
     
     if (LOGICAL_POINTER(byid)[0] || LOGICAL_POINTER(byid)[1]) {
         SEXP dims;
-		PROTECT(dims = NEW_INTEGER(2)); pc++;
+        PROTECT(dims = NEW_INTEGER(2)); pc++;
         INTEGER_POINTER(dims)[0] = n;
         INTEGER_POINTER(dims)[1] = m;
         setAttrib(ans, R_DimSymbol, dims);
@@ -111,35 +109,31 @@ SEXP rgeos_equals(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid) {
     return( rgeos_binpredfunc(env,spgeom1,spgeom2,byid, &GEOSEquals_r) );
 }
 SEXP rgeos_relate(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid) {
-    return( rgeos_binpredfunc(env,spgeom1,spgeom2,byid, &GEOSRelate_r) );
+    return( rgeos_binpredfunc(env,spgeom1,spgeom2,byid, (p_binpredfunc) &GEOSRelate_r) );
 }
 
 SEXP rgeos_binpredfunc(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid, p_binpredfunc binpredfunc) {
 
     GEOSContextHandle_t GEOShandle = getContextHandle(env);
+    int pc = 0;
     
+    GEOSGeom geom1 = rgeos_convert_R2geos(env, spgeom1);
+    int type1 = GEOSGeomTypeId_r(GEOShandle, geom1);
+    
+    GEOSGeom geom2 = (spgeom2 == R_NilValue) ? geom1 : rgeos_convert_R2geos(env, spgeom2);
+    int type2 = GEOSGeomTypeId_r(GEOShandle, geom2);
     
-	GEOSGeom geom1 = rgeos_convert_R2geos(env, spgeom1);
-	int type1 = GEOSGeomTypeId_r(GEOShandle, geom1);
-	
-	GEOSGeom geom2 = (spgeom2 == R_NilValue) ? geom1 : rgeos_convert_R2geos(env, spgeom2);
-	int type2 = GEOSGeomTypeId_r(GEOShandle, geom2);
-	
     int sym_ans = (spgeom2 == R_NilValue);
-
-
-	int m = (LOGICAL_POINTER(byid)[0] && type1 == GEOS_GEOMETRYCOLLECTION) ? 
-				GEOSGetNumGeometries_r(GEOShandle, geom1) : 1;
-    int n = (LOGICAL_POINTER(byid)[1] && type2 == GEOS_GEOMETRYCOLLECTION) ?
-				GEOSGetNumGeometries_r(GEOShandle, geom2) : 1;
-	
     
+    int m = (LOGICAL_POINTER(byid)[0] && type1 == GEOS_GEOMETRYCOLLECTION) ? 
+                GEOSGetNumGeometries_r(GEOShandle, geom1) : 1;
+    int n = (LOGICAL_POINTER(byid)[1] && type2 == GEOS_GEOMETRYCOLLECTION) ?
+                GEOSGetNumGeometries_r(GEOShandle, geom2) : 1;
     if (m == -1) error("rgeos_binpredfunc: invalid number of subgeometries in geometry 1");
     if (n == -1) error("rgeos_binpredfunc: invalid number of subgeometries in geometry 2");
     
-	int pc = 0;
-	SEXP ans;
-    if (binpredfunc == GEOSRelate_r) {
+    SEXP ans;
+    if (binpredfunc == (p_binpredfunc) GEOSRelate_r) {
         PROTECT(ans = NEW_CHARACTER(m*n)); pc++;
     } else {
         PROTECT(ans = NEW_LOGICAL(m*n)); pc++;
@@ -147,7 +141,7 @@ SEXP rgeos_binpredfunc(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid, p_binpre
     
     for(int i=0; i<m; i++) {
         
-		GEOSGeom curgeom1 = (m > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom1, i) : geom1;
+        const GEOSGeometry *curgeom1 = (m > 1) ? GEOSGetGeometryN_r(GEOShandle, geom1, i) : geom1;
         if (curgeom1 == NULL) 
             error("rgeos_binpredfunc: unable to get subgeometries from geometry 1");
 
@@ -155,11 +149,11 @@ SEXP rgeos_binpredfunc(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid, p_binpre
             if(sym_ans && j > i)
                 break;
             
-			GEOSGeom curgeom2 = (n > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom2, j) : geom2;
+            const GEOSGeometry *curgeom2 = (n > 1) ? GEOSGetGeometryN_r(GEOShandle, geom2, j) : geom2;
             if (curgeom2 == NULL) 
                 error("rgeos_binpredfunc: unable to get subgeometries from geometry 2");
             
-            if (binpredfunc == GEOSRelate_r) {
+            if (binpredfunc == (p_binpredfunc) GEOSRelate_r) {
                 char *buf = (char *) GEOSRelate_r(GEOShandle, curgeom1, curgeom2);
                 if (buf == NULL)
                     error("rgeos_isvalidreason: test failed");
@@ -183,7 +177,7 @@ SEXP rgeos_binpredfunc(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid, p_binpre
     
     if (LOGICAL_POINTER(byid)[0] || LOGICAL_POINTER(byid)[1]) {
         SEXP dims;
-		PROTECT(dims = NEW_INTEGER(2)); pc++;
+        PROTECT(dims = NEW_INTEGER(2)); pc++;
         INTEGER_POINTER(dims)[0] = n;
         INTEGER_POINTER(dims)[1] = m;
         setAttrib(ans, R_DimSymbol, dims);
@@ -199,62 +193,62 @@ SEXP rgeos_binpredfunc(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP byid, p_binpre
 
 
 SEXP rgeos_equalsexact(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP tol, SEXP byid) {
-	return( rgeos_binpredfunc_opt(env, spgeom1, spgeom2, tol, byid, FALSE) );
+    return( rgeos_binpredfunc_opt(env, spgeom1, spgeom2, tol, byid, FALSE) );
 }
 
 SEXP rgeos_relatepattern(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP pattern, SEXP byid) {
-	return( rgeos_binpredfunc_opt(env, spgeom1, spgeom2, pattern, byid, 1) );
+    return( rgeos_binpredfunc_opt(env, spgeom1, spgeom2, pattern, byid, 1) );
 }
 
 SEXP rgeos_binpredfunc_opt(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP opt, SEXP byid, int relpat) {
     
-	GEOSContextHandle_t GEOShandle = getContextHandle(env);
+    GEOSContextHandle_t GEOShandle = getContextHandle(env);
     
-	GEOSGeom geom1 = rgeos_convert_R2geos(env, spgeom1);
+    GEOSGeom geom1 = rgeos_convert_R2geos(env, spgeom1);
     int type1 = GEOSGeomTypeId_r(GEOShandle, geom1);
 
-	GEOSGeom geom2 = (spgeom2 == R_NilValue) ? geom1 : rgeos_convert_R2geos(env, spgeom2);
-	int type2 = GEOSGeomTypeId_r(GEOShandle, geom2);
-	
-    int m = (LOGICAL_POINTER(byid)[0] && type1 == GEOS_GEOMETRYCOLLECTION) ? 
-				GEOSGetNumGeometries_r(GEOShandle, geom1) : 1;
-    int n = (LOGICAL_POINTER(byid)[1] && type2 == GEOS_GEOMETRYCOLLECTION) ?
-				GEOSGetNumGeometries_r(GEOShandle, geom2) : 1;
+    GEOSGeom geom2 = (spgeom2 == R_NilValue) ? geom1 : rgeos_convert_R2geos(env, spgeom2);
+    int type2 = GEOSGeomTypeId_r(GEOShandle, geom2);
     
-	int sym_ans = (spgeom2 == R_NilValue);
+    int m = (LOGICAL_POINTER(byid)[0] && type1 == GEOS_GEOMETRYCOLLECTION) ? 
+                GEOSGetNumGeometries_r(GEOShandle, geom1) : 1;
+    int n = (LOGICAL_POINTER(byid)[1] && type2 == GEOS_GEOMETRYCOLLECTION) ?
+                GEOSGetNumGeometries_r(GEOShandle, geom2) : 1;
+    
+    int sym_ans = (spgeom2 == R_NilValue);
          
     
     if (m == -1) error("rgeos_equalsexact: invalid number of subgeometries in geometry 1");
     if (n == -1) error("rgeos_equalsexact: invalid number of subgeometries in geometry 2");
     
-	SEXP ans;
-	int pc=0;
+    SEXP ans;
+    int pc=0;
     PROTECT(ans = NEW_LOGICAL(m*n)); pc++;
       
     for(int i=0; i<m; i++) {
         
-		GEOSGeom curgeom1 = (m > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom1, i) : geom1;
+        const GEOSGeometry *curgeom1 = (m > 1) ? GEOSGetGeometryN_r(GEOShandle, geom1, i) : geom1;
         if (curgeom1 == NULL) 
             error("rgeos_equalsexact: unable to get subgeometries from geometry 1");
         
-		for(int j=0; j<n; j++) {
+        for(int j=0; j<n; j++) {
             if(sym_ans && j > i)
                 break;
             
-			GEOSGeom curgeom2 = (n > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom2, j) : geom2;
+            const GEOSGeometry *curgeom2 = (n > 1) ? (GEOSGeom) GEOSGetGeometryN_r(GEOShandle, geom2, j) : geom2;
             if (curgeom2 == NULL) 
                 error("rgeos_equalsexact: unable to get subgeometries from geometry 2");
             
-			int val;
-			if (relpat) {
-				char patbuf[BUFSIZ];
-		        strcpy(patbuf, CHAR( STRING_ELT(opt, 0) ));
-				val = (int) GEOSRelatePattern_r(GEOShandle, curgeom1, curgeom2, patbuf);
-			} else {
-				val = (int) GEOSEqualsExact_r(GEOShandle, curgeom1, curgeom2, NUMERIC_POINTER(opt)[0] );
+            int val;
+            if (relpat) {
+                char patbuf[BUFSIZ];
+                strcpy(patbuf, CHAR( STRING_ELT(opt, 0) ));
+                val = (int) GEOSRelatePattern_r(GEOShandle, curgeom1, curgeom2, patbuf);
+            } else {
+                val = (int) GEOSEqualsExact_r(GEOShandle, curgeom1, curgeom2, NUMERIC_POINTER(opt)[0] );
             }
 
-			if (val == 2)
+            if (val == 2)
                 error("rgeos_equalsexact: comparison failed");
 
             LOGICAL_POINTER(ans)[n*i+j] = val;
@@ -265,7 +259,7 @@ SEXP rgeos_binpredfunc_opt(SEXP env, SEXP spgeom1, SEXP spgeom2, SEXP opt, SEXP
     
     if (LOGICAL_POINTER(byid)[0] || LOGICAL_POINTER(byid)[1]) {
         SEXP dims;
-		PROTECT(dims = NEW_INTEGER(2)); pc++;
+        PROTECT(dims = NEW_INTEGER(2)); pc++;
         INTEGER_POINTER(dims)[0] = n;
         INTEGER_POINTER(dims)[1] = m;
         setAttrib(ans, R_DimSymbol, dims);
